@@ -4,7 +4,7 @@ import click
 #from .resize import resize
 #from .info import info
 from .removebg import removebg
-
+from .pixelate import pixelate
 
 CONTEXT_SETTINGS = dict(
         help_option_names = [
@@ -18,7 +18,7 @@ def main():
     pass
 
 
-
+main.add_command(pixelate)
 main.add_command(removebg)
 #main.add_command(resize)
 #main.add_command(info)
