@@ -4,6 +4,22 @@ import os
 from PIL import Image
 
 
+def crommakey(value:int, tolerance:int, match_value:int)->bool:
+	if (value-tolerance) >= 0:
+		l_value = value - tolerance
+	else:
+		l_value = 0
+
+	if (value+tolerance) <= 255:
+		u_value = value + tolerance
+	else:
+		u_value = 255
+
+	if match_value < u_value and match_value > l_value:
+		return True
+	else:
+		return False
+
 
 @click.command(
         help="Adds background to any transparent image"
@@ -32,14 +48,22 @@ from PIL import Image
 		show_default=True,
 		help="Color to be removed"
 		)
-def removebg(inputimage, outputimage, color):
+@click.option(
+		'-t',
+		'--tolerance',
+		type=click.INT,
+		default=10,
+		show_default=True,
+		help="Tolerence: amount of color variation for croomakey."
+		)
+def removebg(inputimage, outputimage, color, tolerance):
 	inputimage = Image.open(inputimage)
 	img = inputimage.convert("RGBA")
 	datas = img.getdata()
 	newData = []
 
 	for item in datas:
-		if item[0] == color[0] and item[1] == color[1] and item[2] == color[2]:
+		if crommakey(color[0], tolerance, item[0]) and crommakey(color[1], tolerance, item[1]) and crommakey(color[2], tolerance, item[2]):
 			newData.append((255, 255, 255, 0))
 		else:
 			newData.append(item)
